# Paramga

Paramga is a Genetic Algorithm tool for optimizing model parameters.

# Updating Version

`bumpversion major|minor|patch`

# Push to pypi

`python3 setup.py sdist bdist_wheel`
`python3 -m twine upload dist/*`
